@@ -36,7 +36,7 @@ show_cn_freq_circos <- function(data,
                                 resolution_factor = 1L,
                                 title = c("AMP", "DEL"),
                                 chrs = paste0("chr", 1:22),
-                                genome_build = c("hg19", "hg38", "mm10", "mm9"),
+                                genome_build = c("hg19", "hg38", "T2T", "mm10", "mm9", "ce11"),
                                 cols = NULL,
                                 plot_ideogram = TRUE,
                                 track_height = 0.5,
