@@ -23,7 +23,7 @@
 #' expect_is(x, "data.table")
 #' expect_is(x2, "data.table")
 transform_seg_table <- function(data,
-                                genome_build = c("hg19", "hg38", "mm10", "mm9"),
+                                genome_build = c("hg19", "hg38", "T2T", "mm10", "mm9", "ce11"),
                                 ref_type = c("cytoband", "gene"),
                                 values_fill = NA,
                                 values_fn = function(x, ...) {
